pub fn native_histogram_column_schema() -> Result<ColumnSchema, NativeHistogramError>Expand description
Returns the canonical column schema for a native histogram value.
pub fn native_histogram_column_schema() -> Result<ColumnSchema, NativeHistogramError>Returns the canonical column schema for a native histogram value.